parser

package
v0.8.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 8, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Overview

Package parser provides a recursive descent parser for AQL queries.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Parser

type Parser struct {
	// contains filtered or unexported fields
}

Parser parses AQL queries into an AST.

func New

func New(input string) *Parser

New creates a new parser for the given input.

func (*Parser) Parse

func (p *Parser) Parse() (*ast.Query, error)

Parse parses the input and returns a Query AST.

func (*Parser) ParseStatement

func (p *Parser) ParseStatement() (ast.Statement, error)

ParseStatement parses the input and returns a Statement (Query or Mutation).

Jump to